/**
 * 四舍五入金额
 * @param   {Number} value 要格式化的数字
 * @param   {Number} decimals 保留几位小数
 * @returns {String} 格式化后的数字
 */
const round_half_up_format = (
  value: string,
  decimals: number
): string => {
  if (value) {
    value = `${parseFloat(value).toFixed(decimals)}`
  } else {
    value = parseFloat('0').toFixed(decimals)
  }
  var parts = value.toString().split(".");
  parts[0] = parts[0].replace(/\B(?=(\d{3})+(?!\d))/g, ",");
  return parts.join(".");
};
/*
 * 指定保留的小数位后，直接舍掉后面的数字
 * 参数说明：
 * number：要格式化的数字
 * decimals：保留几位小数
 * dec_point：小数点符号
 * thousands_sep：千分位符号
 * */
const round_floor_format = (number, decimals, dec_point, thousands_sep) => {
  number = (number + '').replace(/[^0-9+-Ee.]/g, '');
  let n = !isFinite(+number) ? 0 : +number,
    prec = !isFinite(+decimals) ? 0 : Math.abs(decimals),
    sep = (typeof thousands_sep === 'undefined') ? '' : thousands_sep,
    dec = (typeof dec_point === 'undefined') ? '.' : dec_point,
    s = '',
    toFixedFix = function (n, prec) {
      const k = Math.pow(10, prec);
      return '' + Math.floor(n * k) / k;
    };

  s = (prec ? toFixedFix(n, prec) : '' + Math.floor(n)).split('.');
  const re = /(-?\d+)(\d{3})/;
  console.log(s);
  while (re.test(s[0])) {
    s[0] = s[0].replace(re, '$1' + sep + '$2');
  }

  if ((s[1] || '').length < prec) {
    s[1] = s[1] || '';
    s[1] += new Array(prec - s[1].length + 1).join('0');
  }
  return s.join(dec);
};

const number2Percentage = (number) => number + '%';
const percentage2Number = (str) => {
  return parseInt(str.split('%')[0]);
};

export default {
  round_half_up_format,
  round_floor_format,
  number2Percentage,
  percentage2Number,
};
